// Example for Controlling pH with Open Source Bio
// A Switching Relay is connected to a base pump, the relay is connected to pin 12 and Ground
// A Switching Relay is connected to an acid pump, the relay is connected to pin 11 and Ground
// If you are only controlling with one pump the loop will still work, just hook up the correct pin

// The commands below are necessary for the OSB library to work
#include <Wire.h>
#include <Boekel_OpenSourceBio.h>
using namespace Boekel;
OpenSourceBio osb; // create osb object.


const int basepump = 12; 
const int acidpump = 11;

//The setup() function will only run once. 
void setup()
{
  delay(1500);  // The main board takes a second to warm up.  This ensures it is ready to communicate
  osb.clearScreen(OpenSourceBio::COLOR_BLACK); // clears user programmable screen 
  pinMode(basepump, OUTPUT); //Setting pin 12 "basepump" as an output 
  pinMode(acidpump, OUTPUT); //Setting pin 11 "acidpump" as an output 
}


//The loop() function will run for ever
void loop()
{

  osb.clearScreen(OpenSourceBio::COLOR_BLACK); // clears user programmable screen
  
  //Creating a varaiable: we will store the "reading" as a double varaible
  double reading;
  
  //The OSB library command below updates the readings from the Transmitter
  osb.updateReadings(); 
  
  //We are setting the reading varaible equal to pH value with the osb.getPH(); command in the OSB library  
  reading = osb.getPH();;  
   
  //Adds base if the pH is less than or equal to 6.5
   if (reading <= 6.5)  
           {
            // Displays text on screen(x,y, text color, background color)
            osb.displayText(100, 100, OpenSourceBio::COLOR_BLUE, OpenSourceBio::COLOR_BLACK,"Adding Base");
            
            digitalWrite(basepump, HIGH); // Turns acid pump relay on 
            delay(2000); //Keep pump on for 2 seconds
            digitalWrite(basepump, LOW); //Turn pump off
            osb.displayText(10, 10, OpenSourceBio::COLOR_BLUE, OpenSourceBio::COLOR_BLACK,"Pausing for 5 seconds");
            delay(5000); //Pauses the pump for 5 seconds to allow for mixing     
            
            }
  else if (reading >= 7.5) // Adds acid if the pH is greater than or equal to 7.5
           {
             
            // Displays text on screen(x,y, text color, background color)
            osb.displayText(100, 100, OpenSourceBio::COLOR_RED, OpenSourceBio::COLOR_BLACK,"Adding Acid");
            
            digitalWrite(acidpump, HIGH); // Turns acid pump relay on 
            delay(2000); //Keep pump on for 2 seconds
            digitalWrite(acidpump, LOW); //Turn pump off
            osb.displayText(10, 10, OpenSourceBio::COLOR_RED, OpenSourceBio::COLOR_BLACK,"Pausing for 5 seconds");
            delay(5000); //Pauses the pump for ten seconds to allow for mixing  
           } 
  else
  
          {
            osb.displayText(60, 100,OpenSourceBio::COLOR_GREEN, OpenSourceBio::COLOR_BLACK,"pH is within range");
            delay(2000); //Delays for 2 seconds
            
          }
  
}
